==> tecfy_core_package-0.1.8.tar.gz: lib/views/base.page.dart <==
part of tecfy_core_client_package;

class BasePage extends Scaffold {
  final String title;
  final List<Widget> appBarActions;
  final Widget appBarBottom;
  final Widget child;
  final FloatingActionButton floatingActionButtonWidget;

  BasePage(BuildContext context, this.title,
      {this.appBarActions,
      this.appBarBottom,
      this.child,
      this.floatingActionButtonWidget})
      : super(
            appBar: LayoutService.isMobile(context)
                ? _getAppBar(context, title, appBarActions, appBarBottom)
                : null,
            drawer: !Navigator.of(context).canPop() &&
                    LayoutService.isMobile(context)
                ? MainDrawer2(title)
                : null,
            floatingActionButton: LayoutService.isMobile(context)
                ? floatingActionButtonWidget
                : null,
            body: build(context, child, title, appBarActions, appBarBottom));

  static Widget build(context, child, title, List appBarActions, appBarBottom) {
    return LayoutService.isMobile(context)
        ? child
        : Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Container(child: MainDrawer2(title), width: ThemeService.menuWidth),
              SizedBox(width:15),
              Expanded(
                  child: Column(children: <Widget>[
                    SizedBox(height: MediaQuery.of(context).padding.top),
                ToolBarComponenet() ,
                //Container(width: MediaQuery.of(context).size.width - 200, height: 100, child: _getAppBar(context,title,appBarActions,appBarBottom)),
                Expanded(                   
                        child: Card(
                        elevation: 10,
                        margin: EdgeInsets.all(10),
                        child: Column(
                          children: <Widget>[
                            Row(children: <Widget>[
                              Navigator.canPop(context) ? TitlePathComponenet(title) : Container(),
                              Spacer(),
                              appBarActions == null ? Container() :  Row(children: appBarActions.where((element) => element != null).toList()),
                              SizedBox(width:5)
                            ],),
                            appBarBottom ?? Container(),
                            Expanded(child: child)
                          ],
                        ))),
              ]))
            ],
          );
  }

  static AppBar _getAppBar(BuildContext context, String title,
      List<Widget> appBarActions, Widget bottom) {
    return MainAppBar(
        context: context,
        backgroundColor: Colors.transparent,
        title: AppLocale.translate(context, title ?? ''),
        actions: LayoutService.isMobile(context) || bottom != null
            ? appBarActions
            : null,
        bottom: bottom ?? getActionsAsBottom(context, appBarActions));
  }

  static PreferredSize getActionsAsBottom(context, appBarActions) {
    if (LayoutService.isMobile(context)) return null;
    return PreferredSize(
        preferredSize: Size(100, 100),
        child: Row(
          children: appBarActions,
          mainAxisAlignment: MainAxisAlignment.end,
        ));
    // return PreferredSize(
    //   preferredSize: Size(LayoutService.getWidth(context),100) ,
    //   child: Align(alignment: Alignment.centerRight,child:Row(children:appBarActions, mainAxisAlignment: MainAxisAlignment.end,))
    // );
  }
}

==> tecfy_core_package-0.1.17.tar.gz: lib/views/base.page.dart <==
part of tecfy_core_client_package;

class BasePage extends Scaffold {
  final String title;
  final List<Widget> appBarActions;
  final Widget appBarBottom;
  final Widget child;
  final FloatingActionButton floatingActionButtonWidget;

  BasePage(BuildContext context, this.title,
      {this.appBarActions,
      this.appBarBottom,
      this.child,
      this.floatingActionButtonWidget})
      : super(
            // key: TecfyCoreApp.appGlobalPagekey,
            appBar: LayoutService.isMobile(context)
                ? _getAppBar(context, title, appBarActions, appBarBottom)
                : null,
            drawer: !Navigator.of(context).canPop() &&
                    LayoutService.isMobile(context)
                ? MainDrawer2(title)
                : null,
            floatingActionButton: LayoutService.isMobile(context)
                ? floatingActionButtonWidget
                : null,
            body: build(context, child, title, appBarActions, appBarBottom));

  static Widget build(context, child, title, List appBarActions, appBarBottom) {
    return LayoutService.isMobile(context)
        ? child
        : Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Container(
                  child: MainDrawer2(title), width: ThemeService.menuWidth),
              SizedBox(width: 15),
              Expanded(
                  child: Column(children: <Widget>[
                SizedBox(height: MediaQuery.of(context).padding.top),
                ToolBarComponenet(),
                //Container(width: MediaQuery.of(context).size.width - 200, height: 100, child: _getAppBar(context,title,appBarActions,appBarBottom)),
                Expanded(
                    child: Card(
                        elevation: 10,
                        margin: EdgeInsets.all(10),
                        child: Column(
                          children: <Widget>[
                            Row(
                              children: <Widget>[
                                Navigator.canPop(context)
                                    ? TitlePathComponenet(title)
                                    : Container(),
                                Spacer(),
                                appBarActions == null
                                    ? Container()
                                    : Row(
                                        children: appBarActions
                                            .where((element) => element != null)
                                            .toList()),
                                SizedBox(width: 5)
                              ],
                            ),
                            appBarBottom ?? Container(),
                            Expanded(child: child)
                          ],
                        ))),
              ]))
            ],
          );
  }

  static AppBar _getAppBar(BuildContext context, String title,
      List<Widget> appBarActions, Widget bottom) {
    return MainAppBar(
        context: context,
        backgroundColor: Colors.transparent,
        title: AppLocale.translate(context, title ?? ''),
        actions: LayoutService.isMobile(context) || bottom != null
            ? appBarActions
            : null,
        bottom: bottom ?? getActionsAsBottom(context, appBarActions));
  }

  static PreferredSize getActionsAsBottom(context, appBarActions) {
    if (LayoutService.isMobile(context)) return null;
    return PreferredSize(
        preferredSize: Size(100, 100),
        child: Row(
          children: appBarActions,
          mainAxisAlignment: MainAxisAlignment.end,
        ));
    // return PreferredSize(
    //   preferredSize: Size(LayoutService.getWidth(context),100) ,
    //   child: Align(alignment: Alignment.centerRight,child:Row(children:appBarActions, mainAxisAlignment: MainAxisAlignment.end,))
    // );
  }
}
